package org.gcube.portlets.user.td.expressionwidget.shared.model.leaf;

import org.gcube.portlets.user.td.expressionwidget.shared.expression.C_MultivaluedExpression;

public class C_Range extends C_Leaf implements C_MultivaluedExpression {

	private static final long serialVersionUID = -2328040312495639444L;
	protected String id = "Range";

	protected TD_Value minimum;
	protected TD_Value maximum;

	public C_Range() {

	}

	public C_Range(TD_Value minimum, TD_Value maximum) {
		this.minimum = minimum;
		this.maximum = maximum;
		if (minimum != null && maximum != null) {
			this.readableExpression = "Range("
					+ minimum.getReadableExpression() + ","
					+ maximum.getReadableExpression() + ")";
		}
	}

	@Override
	public String getId() {
		return id;
	}

	@Override
	public String getIdMulti() {
		return id;
	}

	public TD_Value getMinimum() {
		return minimum;
	}

	public void setMinimum(TD_Value minimum) {
		this.minimum = minimum;
	}

	public TD_Value getMaximum() {
		return maximum;
	}

	public void setMaximum(TD_Value maximum) {
		this.maximum = maximum;
	}

	@Override
	public String getReadableMultivaluedString() {
		return readableExpression;
	}
	
	@Override
	public String toString() {
		return "Range [id=" + id + ", minimum=" + minimum + ", maximum="
				+ maximum + "]";
	}

}
